blacksquare package
===================

Submodules
----------

blacksquare.cell module
-----------------------

.. automodule:: blacksquare.cell
   :members:
   :undoc-members:
   :show-inheritance:

blacksquare.crossword module
----------------------------

.. automodule:: blacksquare.crossword
   :members:
   :undoc-members:
   :show-inheritance:

blacksquare.symmetry module
---------------------------

.. automodule:: blacksquare.symmetry
   :members:
   :undoc-members:
   :show-inheritance:

blacksquare.types module
------------------------

.. automodule:: blacksquare.types
   :members:
   :undoc-members:
   :show-inheritance:

blacksquare.utils module
------------------------

.. automodule:: blacksquare.utils
   :members:
   :undoc-members:
   :show-inheritance:

blacksquare.word module
-----------------------

.. automodule:: blacksquare.word
   :members:
   :undoc-members:
   :show-inheritance:

blacksquare.word\_list module
-----------------------------

.. automodule:: blacksquare.word_list
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: blacksquare
   :members:
   :undoc-members:
   :show-inheritance:
